package edu.institution.userid.hw12.horseAnimation;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;

/**
 * AnimationController shows a multi-image animation with various controls for
 * speed and direction.
 * 
 * To get this to run in your environment:
 * 
 * 1. Change the package specification (see above) to your package name.
 * 
 * 2. Change the IMAGES_PATH constant (see below) to your images directory path.
 * This path is assumed to contain a buttons sub-directory (with button icon
 * images for the control buttons) and a muybridgeHorse sub-directory (with race
 * horse images for the animation).
 * 
 * @author kvlinden, snelesen
 * @version Fall, 2009
 * @version Upgraded for homework 12, Spring, 2012
 */
@SuppressWarnings("serial")
public class AnimationController extends JFrame {

	private final static String IMAGES_PATH = "src/edu/institution/userid/hw12/images/";
	private final static int INITIAL_FRAME_RATE = 20;

	JButton playButton, pauseButton;
	private AnimationPanel animationPanel;

	public AnimationController() throws Exception {
		setTitle("Animation Controller");
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		setLayout(new BorderLayout());

		animationPanel = new AnimationPanel(IMAGES_PATH,
				"muybridgeHorse/Muybridge_race_horse_01.gif");
		animationPanel.init();
		add(animationPanel, BorderLayout.NORTH);

		JPanel controller = new JPanel();
		controller.setLayout(new FlowLayout());

		// the button interface
		playButton = createControlButton("play", new PlayButtonListener());
		controller.add(playButton);
		pauseButton = createControlButton("pause", new PauseButtonListener());
		controller.add(pauseButton);
		playButton.setEnabled(false);
		pauseButton.setEnabled(true);

		animationPanel.play();

		add(controller, BorderLayout.CENTER);
	}

	/**
	 * This utility method constructs control buttons (e.g., play, pause) in a
	 * consistent manner.
	 * 
	 * @param name
	 *            the name of the button (which must match the buttom image's
	 *            filename
	 * @param listener
	 *            the inner class that handles the button pressing event
	 * @return a new button object
	 */
	private JButton createControlButton(String name, ActionListener listener) {
		JButton button = new JButton(new ImageIcon(IMAGES_PATH + "buttons/" + name + ".gif"));
		button.setActionCommand(name);
		button.addActionListener(listener);
		return button;
	}

	/**
	 * This class sets the animation to play mode, which in this stationary
	 * version makes no difference.
	 */
	class PlayButtonListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			animationPanel.play();
			playButton.setEnabled(false);
			pauseButton.setEnabled(true);
		}
	}

	/**
	 * This class sets the animation to pause mode, which in this stationary
	 * version makes no difference.
	 */
	class PauseButtonListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			animationPanel.pause();
			playButton.setEnabled(true);
			pauseButton.setEnabled(false);
		}
	}

	public static void main(String[] args) throws Exception {
		AnimationController application = new AnimationController();
		application.pack();
		application.setVisible(true);
		application.setLocation(100, 100);
	}

}
